.. include:: ../README.rst

.. toctree::
    :caption: Getting started
    :hidden:
    
    installation
    usage
    benchmark

.. toctree::
    :caption: API Documentation
    :hidden:

    api/audiofile

.. toctree::
    :caption: Development
    :hidden:

    contributing
    changelog
